#!/bin/sh

DEFAULT_NTP="time.windows.com"
CHRONY_CONF_FILE="/etc/chrony/chrony.conf"

# move aside original config file
mv -f /etc/chrony/chrony.conf /etc/chrony/chrony.conf.bak

# update permissions on /var/lib/chrony directory
chown -R chrony:chrony /var/lib/chrony

## dynamically populate chrony config file.
{
  echo "# https://github.com/cturra/docker-ntp"
  echo
  echo "# chrony.conf file generated by startup script"
  echo "# located at /opt/startup.sh"
  echo
  echo "# time servers provided by NTP_SERVER environment variables."
} > ${CHRONY_CONF_FILE}


# NTP_SERVERS environment variable is not present, so populate with default server
if [ -z ${NTP_SERVERS} ]; then
  echo "server ${DEFAULT_NTP} iburst" >> ${CHRONY_CONF_FILE}

# check if list of ntp servers provided in NTP_SERVERS environment variable
# are present and is of greater than length 0.
elif [ $(echo ${#NTP_SERVERS}) > 0 ]; then
  IFS=","
  for N in $NTP_SERVERS; do
    # strip any quotes found before or after ntp server
    echo "server "${N//\"}" iburst" >> ${CHRONY_CONF_FILE}
  done

# NTP_SERVERS environment variable is present, but doesn't contain ntp servers, so
# populate with a default server.
else
  echo "server ${DEFAULT_NTP} iburst" >> ${CHRONY_CONF_FILE}
fi

# final bits for the config file
{
  echo "driftfile /var/lib/chrony/chrony.drift"
  echo "makestep 0.1 3"
  echo "rtcsync"
  echo
  echo "allow all"
} >> ${CHRONY_CONF_FILE}

## startup chronyd in the foreground
/usr/sbin/chronyd -d -s
